Bug 1379860 - shipping origin new tab page view by default;r=gijs draft
authorgasolin <gasolin@gmail.com>
Tue, 11 Jul 2017 16:08:58 +0800
changeset 606681 ee64aa9637e66c9383cdb54fe1c4c40368291810
parent 606556 0e41d07a703f19224f60b01577b2cbb5708046c9
child 636830 7a8b59faad1835a937884c185fc792673878b294
push id67771
push userbmo:gasolin@mozilla.com
push dateTue, 11 Jul 2017 08:19:43 +0000
reviewersgijs
bugs1379860
milestone56.0a1
Bug 1379860 - shipping origin new tab page view by default;r=gijs MozReview-Commit-ID: DGVBYXs6WZH
browser/app/profile/firefox.js
browser/base/content/test/newtab/browser_newtab_bug752841.js
--- a/browser/app/profile/firefox.js
+++ b/browser/app/profile/firefox.js
@@ -1256,26 +1256,26 @@ pref("browser.newtabpage.introShown", fa
 
 // Toggles the content of 'about:newtab'. Shows the grid when enabled.
 pref("browser.newtabpage.enabled", true);
 
 // Toggles the directory tiles content of 'about:newtab'.
 sticky_pref("browser.newtabpage.enhanced", true);
 
 // enables Activity Stream inspired layout
-pref("browser.newtabpage.compact", true);
+pref("browser.newtabpage.compact", false);
 
 // enables showing basic placeholders for missing thumbnails
 pref("browser.newtabpage.thumbnailPlaceholder", false);
 
 // number of rows of newtab grid
-pref("browser.newtabpage.rows", 2);
+pref("browser.newtabpage.rows", 3);
 
 // number of columns of newtab grid
-pref("browser.newtabpage.columns", 6);
+pref("browser.newtabpage.columns", 5);
 
 // directory tiles download URL
 pref("browser.newtabpage.directory.source", "https://tiles.services.mozilla.com/v3/links/fetch/%LOCALE%/%CHANNEL%");
 
 // activates Activity Stream
 pref("browser.newtabpage.activity-stream.enabled", false);
 
 // Enable the DOM fullscreen API.
--- a/browser/base/content/test/newtab/browser_newtab_bug752841.js
+++ b/browser/base/content/test/newtab/browser_newtab_bug752841.js
@@ -18,18 +18,18 @@ add_task(async function() {
     {row: 0, column: -1},
     {row: 2, column: 4},
     {row: 2, column: 5},
   ];
 
   // Expected length of grid
   let expectedValues = [1, 1, 1, 1, 8, 10];
 
-   // Values before setting new pref values (12 is the default value -> 6 x 2)
-  let previousValues = [12, 1, 1, 1, 1, 8];
+   // Values before setting new pref values (15 is the default value -> 5 x 3)
+  let previousValues = [15, 1, 1, 1, 1, 8];
 
   await addNewTabPageTab();
   let existingTab = gBrowser.selectedTab;
 
   for (let i = 0; i < expectedValues.length; i++) {
     let existingTabGridLength = await getCellsCount();
     is(existingTabGridLength, previousValues[i],
       "Grid length of existing page before update is correctly.");